==> jc-1.4.0.tar.gz: gnu/xml/pipeline/ValidationConsumer__24Recognizer.h <==
// class gnu.xml.pipeline.ValidationConsumer$Recognizer

// class file dependencies
// @dep_class c3c82d7a3ea2ae0e gnu_xml_pipeline_ValidationConsumer__24Recognizer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_pipeline_ValidationConsumer__24Recognizer_H_
#define _JC_gnu_xml_pipeline_ValidationConsumer__24Recognizer_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object;
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_refs	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$refs	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object;

typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vmethods	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vmethods;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtable	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtable;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtype	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method$_init$e3a1cb21679f8576(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object *);

// Virtual methods
extern jboolean _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method$acceptCharacters$f1bf4dfd6e39a802(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *);
extern struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method$acceptElement$99cdc60944f2d23c(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *, struct _jc_java_lang_String$object *);
extern jboolean _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method$completed$0cd53b1aa4c5889f(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method_info$acceptCharacters$f1bf4dfd6e39a802;
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method_info$acceptElement$99cdc60944f2d23c;
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method_info$completed$0cd53b1aa4c5889f;
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vmethods {
	jboolean	(*acceptCharacters$f1bf4dfd6e39a802)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *);
	struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object	*(*acceptElement$99cdc60944f2d23c)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *, struct _jc_java_lang_String$object *);
	jboolean	(*completed$0cd53b1aa4c5889f)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *);
};

// Vtable
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vmethods	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
};

// Vtype
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_refs {
	struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object	*type;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$refs {
    _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_refs	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_nonrefs	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object {
	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtype	*vtype;
	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtype _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_ValidationConsumer__24Recognizer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$class_object;

#endif	/* _JC_gnu_xml_pipeline_ValidationConsumer__24Recognizer_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/pipeline/ValidationConsumer__24Recognizer.h <==
// class gnu.xml.pipeline.ValidationConsumer$Recognizer

// class file dependencies
// @dep_class c3c82d7a3ea2ae0e gnu_xml_pipeline_ValidationConsumer__24Recognizer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_pipeline_ValidationConsumer__24Recognizer_H_
#define _JC_gnu_xml_pipeline_ValidationConsumer__24Recognizer_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object;
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_refs	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$refs	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object;

typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vmethods	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vmethods;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtable	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtable;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtype	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method$_init$e3a1cb21679f8576(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method$acceptCharacters$f1bf4dfd6e39a802(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method$acceptElement$99cdc60944f2d23c(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method$completed$0cd53b1aa4c5889f(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method_info$acceptCharacters$f1bf4dfd6e39a802;
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method_info$acceptElement$99cdc60944f2d23c;
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method_info$completed$0cd53b1aa4c5889f;
extern _jc_method _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vmethods {
	jboolean	(*acceptCharacters$f1bf4dfd6e39a802)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *) _JC_JCNI_ATTR;
	struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object	*(*acceptElement$99cdc60944f2d23c)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	jboolean	(*completed$0cd53b1aa4c5889f)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vmethods	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
};

// Vtype
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_refs {
	struct _jc_gnu_xml_pipeline_ValidationConsumer__24ElementInfo$object	*type;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$refs {
    _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_refs	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$sub_nonrefs	gnu_xml_pipeline_ValidationConsumer__24Recognizer;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$object {
	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtype	*vtype;
	_jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$vtype _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_ValidationConsumer__24Recognizer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_ValidationConsumer__24Recognizer$class_object;

#endif	/* _JC_gnu_xml_pipeline_ValidationConsumer__24Recognizer_H_ */
